<?php
namespace ElementorBlogRevolution\Widgets;

use \Elementor\Controls_Manager as Controls_Manager;
use \Elementor\Frontend;
use \Elementor\Group_Control_Border as Group_Control_Border;
use \Elementor\Group_Control_Box_Shadow as Group_Control_Box_Shadow;
use \Elementor\Group_Control_Typography as Group_Control_Typography;
use \Elementor\Utils as Utils;
use \Elementor\Widget_Base as Widget_Base;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

/**
 * Elementor Blog Revolution
 *
 *
 * @since 1.0.0
 */
class Blog_Revolution extends Widget_Base {

	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'blog-revolution';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Blog Revolution', 'blogrevolutionelementor' );
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-posts-grid';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'general' ];
	}

	/**
	 * Retrieve the list of scripts the widget depended on.
	 *
	 * Used to set scripts dependencies required to run the widget.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget scripts dependencies.
	 */
	public function get_script_depends() {
		return [ 'blogrevolutionelementor' ];
	}

	/**
	 * Get post type categories.
	 */
	private function grid_get_all_post_type_categories( $post_type ) {
		$options = array();

		if ( $post_type == 'post' ) {
			$taxonomy = 'category';
		} else {
			$taxonomy = $post_type;
		}

		if ( ! empty( $taxonomy ) ) {
			// Get categories for post type.
			$terms = get_terms(
				array(
					'taxonomy'   => $taxonomy,
					'hide_empty' => false,
				)
			);
			if ( ! empty( $terms ) ) {
				foreach ( $terms as $term ) {
					if ( isset( $term ) ) {
						if ( isset( $term->slug ) && isset( $term->name ) ) {
							$options[ $term->slug ] = $term->name;
						}
					}
				}
			}
		}

		return $options;
	}

	/**
	 * Get post type categories.
	 */
	private function grid_get_all_custom_post_types() {
		$options = array();

		$args = array( '_builtin' => false );
		$post_types = get_post_types( $args, 'objects' );

		foreach ( $post_types as $post_type ) {
			if ( isset( $post_type ) ) {
					$options[ $post_type->name ] = $post_type->label;
			}
		}

		return $options;
	}

	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */


protected function _register_controls() {


/***********STYLE***********/
$this->start_controls_section(
	'section_style',
	[
		'label' => esc_html__( 'Style', 'blogrevolutionelementor' ),
	]
);


		/***********STYLE POST***********/
		$this->add_control(
			'style_post',
			[
				'label' => esc_html__( 'Style', 'blogrevolutionelementor' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'style1',
				'options' => [
					'style1' => esc_html__( 'Style 1', 'blogrevolutionelementor' ),
					'style2' => esc_html__( 'Style 2', 'blogrevolutionelementor' ),
					'style3' => esc_html__( 'Style 3', 'blogrevolutionelementor' ),
				]
			]
		);
		/***********END STYLE POST***********/


		$this->add_control(
 			'hr6',
 			[
 				'type' => \Elementor\Controls_Manager::DIVIDER,
 			]
 	 );


		/***********COLUMNS***********/
		$this->add_control(
			'columns',
			[
				'label' => esc_html__( 'Columns', 'blogrevolutionelementor' ),
				'type' => Controls_Manager::SELECT,
				'default' => '2',
				'options' => [
					'1' => '1',
					'2' => '2',
					'3' => '3'
				]
			]
		);
	 /***********END COLUMNS***********/

	 $this->add_control(
			'hr7',
			[
				'type' => \Elementor\Controls_Manager::DIVIDER,
			]
	 );

	/***********BOX ALIGN***********/
	$this->add_control(
				'box_align',
				[
					'label' => esc_html__( 'Box Alignment', 'blogrevolutionelementor' ),
					'type' => \Elementor\Controls_Manager::CHOOSE,
					'options' => [
						'left' => [
							'title' => esc_html__( 'Left', 'blogrevolutionelementor' ),
							'icon' => 'fa fa-align-left',
						],
						'center' => [
							'title' => esc_html__( 'Center', 'blogrevolutionelementor' ),
							'icon' => 'fa fa-align-center',
						],
						'right' => [
							'title' => esc_html__( 'Right', 'blogrevolutionelementor' ),
							'icon' => 'fa fa-align-right',
						],
						'justify' => [
							'title' => esc_html__( 'Justify', 'blogrevolutionelementor' ),
							'icon' => 'fa fa-align-justify',
						],
					],
					'default' => 'center',
					'toggle' => true,
				]
	);
	/***********END BOX ALIGN***********/

	$this->add_control(
		 'hr11',
		 [
			 'type' => \Elementor\Controls_Manager::DIVIDER,
		 ]
	);


	/***********TITLE COLOR***********/
	$this->add_control(
				'title_color',
				[
					'label' => esc_html__( 'Title Color', 'blogrevolutionelementor' ),
					'type' => \Elementor\Controls_Manager::COLOR,
					'default' => '#777777',
			  ]
	);
	/***********END TITLE COLOR***********/


	$this->add_control(
		 'hr12',
		 [
			 'type' => \Elementor\Controls_Manager::DIVIDER,
		 ]
	);


	/***********CATEGORY-INFO COLOR***********/
	$this->add_control(
		'category_info_color',
		[
			'label' => esc_html__( 'Category/Info Color', 'blogrevolutionelementor' ),
			'type' => \Elementor\Controls_Manager::COLOR,
			'default' => '#777777',
		]
	);
	/***********END CATEGORY-INFO COLOR***********/

	$this->add_control(
		 'hr13',
		 [
			 'type' => \Elementor\Controls_Manager::DIVIDER,
		 ]
	);


	/***********TEXT COLOR***********/
	$this->add_control(
				'text_color',
				[
					'label' => esc_html__( 'Text Color', 'blogrevolutionelementor' ),
					'type' => \Elementor\Controls_Manager::COLOR,
					'default' => '#777777',

		    ]
	);
	/***********END TEXT COLOR***********/

	$this->add_control(
		 'hr14',
		 [
			 'type' => \Elementor\Controls_Manager::DIVIDER,
		 ]
	);


	/***********HOVER COLOR***********/
	$this->add_control(
				'hover_color',
				[
					'label' => esc_html__( 'Hover Color', 'blogrevolutionelementor' ),
					'type' => \Elementor\Controls_Manager::COLOR,
					'default' => '#333333',

		    ]
	);
	/***********END TITLE COLOR***********/





$this->end_controls_section();

/***********END STYLE***********/




/***********SHOW\POSITION BLOCK***********/
$this->start_controls_section(
	'section_content',
	[
		'label' => esc_html__( 'Show\Position Block', 'blogrevolutionelementor' ),
	]
);



 /***********TTITLE***********/
 $this->add_control(
	 'show_title',
	 [
		 'label' => esc_html__( 'Show Title', 'blogrevolutionelementor' ),
		 'type' => \Elementor\Controls_Manager::SWITCHER,
		 'yes' => esc_html__( 'Show', 'blogrevolutionelementor' ),
		 'off' => esc_html__( 'Hide', 'blogrevolutionelementor' ),
		 'return_value' => 'yes',
		 'default' => 'yes'
	 ]
 );


$this->add_control(
 'position_title',
 [
	 'label' => esc_html__( 'Position Title', 'blogrevolutionelementor' ),
	 'type' => Controls_Manager::SELECT,
	 'default' => '1',
	 'options' => [
		 '1' => '1',
		 '2' => '2',
		 '3' => '3',
		 '4' => '4',
		 '5' => '5',
	 ],
	'condition'	=> [
		'show_title'	=> 'yes'
	]
 ]
);
/***********END TTITLE***********/


$this->add_control(
'hr2',
[
	'type' => \Elementor\Controls_Manager::DIVIDER,
]
);

/***********IMAGE***********/
$this->add_control(
 'show_img',
 [
	 'label' => esc_html__( 'Show Image', 'blogrevolutionelementor' ),
	 'type' => \Elementor\Controls_Manager::SWITCHER,
	 'yes' => esc_html__( 'Show', 'blogrevolutionelementor' ),
	 'off' => esc_html__( 'Hide', 'blogrevolutionelementor' ),
	 'return_value' => 'yes',
	 'default' => 'yes'
 ]
);


$this->add_control(
'position_img',
 [
	 'label' => esc_html__( 'Position Img', 'blogrevolutionelementor' ),
	 'type' => Controls_Manager::SELECT,
	 'default' => '2',
	 'options' => [
		 '1' => '1',
		 '2' => '2',
		 '3' => '3',
		 '4' => '4',
		 '5' => '5',
	 ],
	'condition'	=> [
		'show_img'	=> 'yes'
 ]
]
);
/***********END IMAGE***********/

$this->add_control(
'hr3',
[
 'type' => \Elementor\Controls_Manager::DIVIDER,
]
);



/***********CONTENT***********/
$this->add_control(
'show_content',
 [
	 'label' => esc_html__( 'Show Content', 'blogrevolutionelementor' ),
	 'type' => \Elementor\Controls_Manager::SWITCHER,
	 'yes' => esc_html__( 'Show', 'blogrevolutionelementor' ),
	 'off' => esc_html__( 'Hide', 'blogrevolutionelementor' ),
	 'return_value' => 'yes',
	 'default' => 'yes'
 ]
);


$this->add_control(
'position_content',
[
	'label' => esc_html__( 'Position Content', 'blogrevolutionelementor' ),
	'type' => Controls_Manager::SELECT,
	'default' => '3',
	'options' => [
		'1' => '1',
		'2' => '2',
		'3' => '3',
		'4' => '4',
		'5' => '5',
	],
 'condition'	=> [
	 'show_content'	=> 'yes'
 ]
]
);





$this->add_control(
'number_excerpt',
[
	'label' => esc_html__( 'Number Excerpt', 'blogrevolutionelementor' ),
	'type' => \Elementor\Controls_Manager::TEXT,
	'default' => '200',
	'placeholder' => esc_html__( 'Add your Number of Excerpt', 'blogrevolutionelementor' ),
]
);



/***********END CONTENT***********/

$this->add_control(
'hr4',
[
'type' => \Elementor\Controls_Manager::DIVIDER,
]
);


/***********CATEGORY***********/
$this->add_control(
'show_category',
[
	'label' => esc_html__( 'Show Category', 'blogrevolutionelementor' ),
	'type' => \Elementor\Controls_Manager::SWITCHER,
	'yes' => esc_html__( 'Show', 'blogrevolutionelementor' ),
	'off' => esc_html__( 'Hide', 'blogrevolutionelementor' ),
	'return_value' => 'yes',
	'default' => 'yes'
]
);


$this->add_control(
'position_category',
[
	'label' => esc_html__( 'Position Category', 'blogrevolutionelementor' ),
	'type' => Controls_Manager::SELECT,
	'default' => '5',
	'options' => [
		'1' => '1',
		'2' => '2',
		'3' => '3',
		'4' => '4',
		'5' => '5',
	],
 'condition'	=> [
	 'show_category'	=> 'yes'
 ]
]
);
/***********END CATEGORY***********/


$this->add_control(
'hr5',
[
'type' => \Elementor\Controls_Manager::DIVIDER,
]
);


/***********INFO***********/
$this->add_control(
'show_info',
[
'label' => esc_html__( 'Show Info', 'blogrevolutionelementor' ),
'type' => \Elementor\Controls_Manager::SWITCHER,
'yes' => esc_html__( 'Show', 'blogrevolutionelementor' ),
'off' => esc_html__( 'Hide', 'blogrevolutionelementor' ),
'return_value' => 'yes',
'default' => 'yes'
]
);

$this->add_control(
'position_info',
[
 'label' => esc_html__( 'Position Info', 'blogrevolutionelementor' ),
 'type' => Controls_Manager::SELECT,
 'default' => '3',
 'options' => [
	 '1' => '1',
	 '2' => '2',
	 '3' => '3',
	 '4' => '4',
	 '5' => '5',
 ],
'condition'	=> [
	'show_info'	=> 'yes'
]
]
);

$this->add_control(
'show_author',
[
'label' => esc_html__( 'Show Author', 'blogrevolutionelementor' ),
'type' => \Elementor\Controls_Manager::SWITCHER,
'yes' => esc_html__( 'Show', 'blogrevolutionelementor' ),
'off' => esc_html__( 'Hide', 'blogrevolutionelementor' ),
'return_value' => 'yes',
'default' => 'yes',
'condition'	=> ['show_info'	=> 'yes']
]
);

$this->add_control(
'show_date',
[
'label' => esc_html__( 'Show Date', 'blogrevolutionelementor' ),
'type' => \Elementor\Controls_Manager::SWITCHER,
'yes' => esc_html__( 'Show', 'blogrevolutionelementor' ),
'off' => esc_html__( 'Hide', 'blogrevolutionelementor' ),
'return_value' => 'yes',
'default' => 'yes',
'condition'	=> ['show_info'	=> 'yes']
]
);

$this->add_control(
'show_comment',
[
'label' => esc_html__( 'Show Comment', 'blogrevolutionelementor' ),
'type' => \Elementor\Controls_Manager::SWITCHER,
'yes' => esc_html__( 'Show', 'blogrevolutionelementor' ),
'off' => esc_html__( 'Hide', 'blogrevolutionelementor' ),
'return_value' => 'yes',
'default' => 'yes',
'condition'	=> ['show_info'	=> 'yes']
]
);

/***********END INFO***********/



$this->end_controls_section();
/***********END SHOW\POSITION BLOCK***********/



/***********QUERY***********/
$this->start_controls_section(
	'section_query',
	[
		'label' => esc_html__( 'QUERY', 'blogrevolutionelementor' )
	]
);

$this->add_control(
'source',
[
	'label' => esc_html__( 'Source', 'blogrevolutionelementor' ),
	'type' => Controls_Manager::SELECT,
	'default' => 'wp_posts',
	'options' => [
		'wp_posts' 				=> esc_html__( 'Wordpress Posts', 'blogrevolutionelementor' ),
		'post_type' 	=> esc_html__( 'Custom Posts Type', 'blogrevolutionelementor' )
	]
]
);

$this->add_control(
'posts_source',
[
	'label' => esc_html__( 'All Posts/Sticky posts', 'blogrevolutionelementor' ),
	'type' => Controls_Manager::SELECT,
	'default' => 'all_posts',
	'options' => [
		'all_posts' 			=> esc_html__( 'All Posts', 'blogrevolutionelementor' ),
		'onlystickyposts'	=> esc_html__( 'Only Sticky Posts', 'blogrevolutionelementor' )
	],
	'condition'	=> [
		'source'	=> 'wp_posts'
	]
]
);

$this->add_control(
'posts_type',
[
	'label' => esc_html__( 'Select Post Type Source', 'blogrevolutionelementor' ),
	'type' => Controls_Manager::SELECT,
	'options' => $this->grid_get_all_custom_post_types(),
	'condition'	=> [
		'source'	=> 'post_type'
	]
]
);

$this->add_control(
'categories',
[
	'label' => esc_html__( 'Categories', 'blogrevolutionelementor' ),
	'type' => Controls_Manager::SELECT2,
	'multiple' => true,
	'options' => $this->grid_get_all_post_type_categories('post'),
	'condition'	=> [
		'source'	=> 'wp_posts'
	]
]
);

$this->add_control(
'order',
[
	'label' => esc_html__( 'Order', 'blogrevolutionelementor' ),
	'type' => Controls_Manager::SELECT,
	'default' => 'DESC',
	'options' => [
		'DESC'	=> 'DESC',
		'ASC' 	=> 'ASC'
	]
]
);

$this->add_control(
'orderby',
[
	'label' => esc_html__( 'Order By', 'blogrevolutionelementor' ),
	'type' => Controls_Manager::SELECT,
	'default' => 'date',
	'options' => [
		'date'			=> 'Date',
		'ID' 			=> 'ID',
		'author' 		=> 'Author',
		'title' 		=> 'Title',
		'name' 			=> 'Name',
		'modified'		=> 'Modified',
		'parent' 		=> 'Parent',
		'rand' 			=> 'Rand',
		'comment_count' => 'Comments Count',
		'none' 			=> 'None'
	]
]
);



$this->add_control(
'pagination',
[
	'label' => esc_html__( 'Pagination', 'blogrevolutionelementor' ),
	'type' => Controls_Manager::SELECT,
	'default' => 'no',
	'options' => [
		'no'	=> 'No',
		'yes' 	=> 'Yes',
		'load-more' => 'Yes with Load More'
	]
]
);

$this->add_control(
'num_posts',
[
	'label' => esc_html__( 'Number Posts', 'blogrevolutionelementor' ),
	'type' => Controls_Manager::TEXT,
	'default' => '10',
	'condition'	=> [
		'pagination'	=> 'no'
	]
]
);

$this->add_control(
'pagination_type',
[
	'label' => esc_html__( 'Pagination Type', 'blogrevolutionelementor' ),
	'type' => Controls_Manager::SELECT,
	'default' => 'numeric',
	'options' => [
		'numeric'	=> 'Numeric',
		'normal' 	=> 'Normal'
	],
	'condition'	=> [
		'pagination'	=> 'yes'
	]
]
);

$this->add_control(
'num_posts_page',
[
	'label' => esc_html__( 'Number Posts For Page', 'blogrevolutionelementor' ),
	'label_block' => true,
	'type' => Controls_Manager::TEXT,
	'default' => '10',
	'condition'	=> [
		'pagination'	=> array('yes','load-more')
	]
]
);

$this->end_controls_section();






}


    /**
    * Render the widget output on the frontend.
    *
    * Written in PHP and used to generate the final HTML.
    *
    * @since 1.0.0
    *
    * @access protected
    */


   protected function render() {
     static $instance = 0;
     $instance++;
     $settings = $this->get_settings_for_display();

     $columns              = esc_html($settings['columns']);
		 $source					= esc_html($settings['source']);
		 $posts_source			= esc_html($settings['posts_source']);
		 $posts_type				= esc_html($settings['posts_type']);
		 $categories				= '';
		 if(!empty($settings['categories'])) {
			 $num_cat = count($settings['categories']);
			 $i = 1;
			 foreach ( $settings['categories'] as $element ) {
				 $categories .= $element;
				 if($i != $num_cat) {
					 $categories .= ',';
				 }
				 $i++;
			 }
		 }
		 $categories_post_type					= '';
		 $pagination										= esc_html($settings['pagination']);
		 $pagination_type								= esc_html($settings['pagination_type']);
		 $num_posts_page								= esc_html($settings['num_posts_page']);
		 $num_posts											= esc_html($settings['num_posts']);
		 $orderby												= esc_html($settings['orderby']);
		 $order													= esc_html($settings['order']);
		 $box_align     								= esc_html($settings['box_align']);
		 $style_post    								= esc_html($settings['style_post']);
		 $css_link 											= '';
     $css_current_pag_num 					= '';


		 wp_enqueue_style( 'elementor-icons' );
		 wp_enqueue_style( 'font-awesome' );


     //COLONNE
     if($columns == '1') : $columns_class = 'col-md-12';  endif;
 		 if($columns == '2') : $columns_class = 'col-md-6'; endif;
 		 if($columns == '3') : $columns_class = 'col-md-4'; endif;
 		 if(empty($num_posts)) : $num_posts = 6; endif;

		 // PAGINATION
 		if($pagination == 'yes') {
 			if ( get_query_var('paged') ) {
 				$paged = get_query_var('paged');
 			} elseif ( get_query_var('page') ) {
 				$paged = get_query_var('page');
 			} else {
 				$paged = 1;
 			}
 		}
 		// #PAGINATION

		 // Load More
 		if($pagination == 'load-more') :
 			$class_load_more = 'blogrevolution-bp-load-more-'.$blog_style.'';
 			$class_item_load_more = 'blogrevolution-bp-item-load-more-'.$blog_style.'';
 		endif;
 		// #Load More

 		// LOOP QUERY
 		$query = blogrevolution_query( $source,
 							$posts_source,
 							$posts_type,
 							$categories,
 							$categories_post_type,
 							$order,
 							$orderby,
 							$pagination,
 							$pagination_type,
 							$num_posts,
 							$num_posts_page );
     $count = 1;
     $loop = new \WP_Query($query);


     echo "<div class='blogrevolution box-align-".$box_align." style-".$style_post."'>";

       if($loop) :
   			while ( $loop->have_posts() ) : $loop->the_post();
					$id = get_the_id();

        echo "<div class='". $columns_class ."'>";
				echo '<div class="box_post">';
					box_position($settings,$id);
				echo '</div>';

        echo "</div>";

        $count++;
        endwhile;
      endif;

			echo "</div>";/*CHIUSURA blogrevolution*/


			/**********************************************************************/
			/****************************** PAGINATION ****************************/
			/**********************************************************************/
			if($pagination == 'yes') {
					echo '<div class="clear"></div><div class="blogrevolution-bp-blogs-display-'.esc_html($instance).' blogrevolution-bp-vc-pagination">';
					if($pagination_type == 'numeric') {
						echo blogrevolution_posts_numeric_pagination($pages = '', $range = 2,$loop,$paged,$css_current_pag_num,$css_link);
					} else {
						echo '<div class="blogrevolution-bp-pagination-normal">';
							echo get_next_posts_link( '<span class="older" '.$css_link.'><i class="fas fa-angle-double-left"></i>Older blogs</span>', $loop->max_num_pages );
							echo get_previous_posts_link( '<span class="newer" '.$css_link.'>Newer blogs<i class="fas fa-angle-double-right"></i></span>' );
						echo '</div>';
					}
					echo '<div class="clear"></div></div>';
			}
			/**********************************************************************/
			/***************************** #PAGINATION ****************************/
			/**********************************************************************/
			wp_reset_query();
			echo '</div>';


   }



   protected function _content_template() {}
   }
